require 'uri'
require 'cgi'
require 'net/http'
require 'active_support'
require 'active_support/core_ext/object'
require 'terminal-table'

require 'mocloud/utils'
require 'mocloud/api'

module Mocloud
module Commands

	class Stacks
		def description
			"List your stacks"
		end

		def run
			Trollop::options do
				banner <<-ENDOFHELP
Usage: mobingi stacks [options]"

Shows the stacks on your Mobingi account

				ENDOFHELP
			end

			creds = Mocloud::Utils::Credentials.new
			user = creds.read_credentials()
				token = creds.make_token(0)

			api = Mocloud::API.new
			res = api.get ("/v1/describe/#{user['uid']}/stack")

			Mocloud::Utils.handle_error(res, "Show stacks failed")

			data = JSON.parse(res[:body])

			output = data.map do |x| 
			{ 
				:id => x["stack_id"]["S"], 
				:nick => x["nickname"]["S"], 
				:instance_count => x["instances"]["L"].length 
			} 
			end

			puts "List of stacks:"

			rows = []
			output.each do |x|

				rows << [x[:nick], x[:id], x[:instance_count]]

			end

			table = Terminal::Table.new :headings => ['Name', 'ID', 'Instances'], :rows => rows

			puts table

		end
	end
	
end
end